require('isomorphic-fetch')

// authentication url
const authUrl = process.env.AUTH_URL
// create basic authentication with id and secret
const basicAuth = Buffer.from(`${process.env.XMDS_CLIENT_ID}:${process.env.XMDS_SECRET}`).toString('base64')
// get access token from authentication server
const doc = await fetch(authUrl, {
  headers: {
    Authorization: `Basic ${basicAuth}`,
    'Content-Type': 'application/json'
  },
  method: 'POST'
}).then(res => res.json())
const accessToken = doc.access_token
console.log('access token', accessToken)
;

const { pluck, prop, map } = require('ramda')
const patientId = 'smart-1685497'
const patient = await fetch('https://r2.smarthealthit.org/Patient/' + patientId)
.then(res => res.json())
.then(patient => ({resource: patient}))
const medications = await fetch('https://r2.smarthealthit.org/MedicationOrder?patient=' + patientId)
  .then(res => res.json())
  .then(bundle => pluck('resource', prop('entry', bundle)))
  .then(pluck('medicationCodeableConcept'))
  .then(map(med => ({resource: { resourceType: 'Medication', code: med }})))

;

const bundle = {
  resourceType: 'Bundle',
  type: 'collection',
  
  entry: [
    patient,
    ...medications
  ]
}
JSON.stringify(bundle, null, 2);

const result = await fetch(`${process.env.XMDS_URL}/profiles`, {
  method: 'POST',
  headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  },
  body: JSON.stringify(bundle)
}).then(res => res.json())

const profileId = result.id

result;

const score = await fetch(`${process.env.XMDS_URL}/profiles/${result.id}/riskscore`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
score.html;
const matrix = await fetch(`${process.env.XMDS_URL}/profiles/${result.id}/matrix`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
matrix.html;
const bullseye = await fetch(`${process.env.XMDS_URL}/profiles/${result.id}/bullseye`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
bullseye.html;
const windrose = await fetch(`${process.env.XMDS_URL}/profiles/${result.id}/windrose`, {
headers: {
    'Content-Type': 'application/json',
    Authorization: `Bearer ${accessToken}`
  }
})
  .then(res => res.json())
  
windrose.html;
